==> haskell-tasty-lua-1.1.1.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-AEm6ePrSipxEHDBZGm8MPs
key:                  tasty-lua-1.1.1.1-AEm6ePrSipxEHDBZGm8MPs
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  d17d925fd94e67ff4509cf6e3d6e260a
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-AEm6ePrSipxEHDBZGm8MPs
depends:
    QuickCheck-2.15.0.1-2pZpRuW8a4m1OLZKRhi2a3 base-4.17.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    hslua-core-2.3.2-IX6Eig5Vz3ak8lu2NldBs
    hslua-marshalling-2.3.1-Ch0sgVjYNJgE8Vnbls0SCD
    lua-arbitrary-1.0.1.1-FWC4ghIAJlb9kUep74bT30
    tasty-1.5-9b9FHG8OBttDZ68785yCzt

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-1.1.1.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-CzMYnWOzlBH4rxHBBcKa6k
key:                  tasty-lua-1.1.1.1-CzMYnWOzlBH4rxHBBcKa6k
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  bc4cb9f4f957e9649270a2bec167b57f
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-CzMYnWOzlBH4rxHBBcKa6k
depends:
    QuickCheck-2.15.0.1-Ev8f4YvWcjR3aGAT6KgUIz base-4.17.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    hslua-core-2.3.2-AivjYvYsnbjDnUwQjQMPES
    hslua-marshalling-2.3.1-6lR3cswWtSX2NmZupbfl7a
    lua-arbitrary-1.0.1.1-Blsyb7RLmsKIdO5sJn6lrc
    tasty-1.5-KfqPODqIxWIB9zLnFruxu2

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
